==> humhub-1.17.5.zip: humhub-1.17.5/protected/humhub/modules/user/messages/it/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => 'Impostazioni dell\'<strong>account</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Conferma</strong> il tuo nuovo indirizzo email',
    '<strong>Permissions</strong>' => '<strong>Autorizzazioni</strong>',
    '<strong>Your</strong> Account' => 'Il <strong>Tuo</strong> Account',
    '<strong>Your</strong> profile' => '<strong>Il tuo</strong> profilo',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Aggiungi tag al tuo profilo descrivendoti ed evidenziando le tue capacità e i tuoi interessi. I tuoi tag verranno visualizzati nel tuo profilo e nella directory "Persone".',
    'All your personal data will be irrevocably deleted.' => 'Tutti i tuoi dati personali verranno definitivamente eliminati.',
    'Are you sure that you want to delete your account?' => 'Sei sicuro di voler eliminare il tuo account?',
    'Blocked users' => 'Utenti bloccati',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'La modifica del nome utente può rendere inutilizzabili alcuni collegamenti, ad esempio vecchi collegamenti al profilo.',
    'Confirm' => 'Conferma',
    'Current password' => 'Password attuale',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Definisci le impostazioni di base per il tuo profilo. Puoi aggiungere tag adatti a te, scegliere la lingua e il fuso orario e bloccare gli utenti maleducati.',
    'Delete account' => 'Elimina account',
    'Do you really want to delete your icon image?' => 'Vuoi veramente cancellare l\'immagine dell\'icona?',
    'Do you really want to delete your logo image?' => 'Vuoi veramente eliminare la tua immagine?',
    'E-Mail' => 'Email',
    'E-Mail change' => 'Cambia e-mail',
    'Enter your password to continue' => 'Inserisci la tua password per continuare',
    'General' => 'Generale',
    'Hello' => 'Ciao',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Qui puoi modificare i tuoi dati generali del profilo, che sono visibili nella pagina personale del tuo profilo.',
    'Hide introduction tour panel on dashboard' => 'Nascondi il pannello tour introduttivo sulla bacheca',
    'Hide my online status' => 'Nascondere il mio stato online',
    'Invalid link! Please make sure that you entered the entire url.' => 'Link non valido! Assicurati di aver inserito l\'intero URL.',
    'Language' => 'Lingua',
    'Markdown Editor Mode' => 'Modalità editor Markdown',
    'Modules' => 'Moduli',
    'New E-Mail address' => 'Nuovo indirizzo e-mail',
    'New User name' => 'Nuovo nome utente',
    'Not registered users' => 'Utenti non registrati',
    'Notifications' => 'Notifiche',
    'Other users' => 'Altri utenti',
    'Password Recovery' => 'Recupera password',
    'Permissions' => 'Permessi',
    'Profile' => 'Profilo',
    'Profile Tags' => 'Tag del profilo',
    'Profile visibility' => 'Visibilità profilo',
    'Registered users only' => 'Solo utenti registrati',
    'Save' => 'Salva',
    'Save profile' => 'Salva il profilo',
    'The entered e-mail address is already in use by another user.' => 'La mail inserita è già stata utilizzata da un altro utente.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Queste impostazioni ti consentono di determinare quali autorizzazioni vuoi concedere ai visitatori del tuo profilo personale. Ogni utente può regolare liberamente le impostazioni per il proprio profilo.',
    'TimeZone' => 'Fuso orario',
    'Username has been changed' => 'Il nome utente è stato cambiato',
    'Users' => 'Persone',
    'Visible for all (also unregistered users)' => 'Visibile a tutti (anche utenti non registrati)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Abbiamo appena inviato un\'e-mail di conferma al tuo nuovo indirizzo. <br> Si prega di seguire le istruzioni all\'interno.',
    'You are currently the owner of following spaces:' => 'Sei il proprietario dei seguenti spazi:',
    'You cannot use this username.' => 'Non puoi usare questo nome utente.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Hai richiesto di modificare il tuo indirizzo e-mail.<br>Il tuo nuovo indirizzo e-mail è {newemail}.<br><br>Per confermare il tuo nuovo indirizzo e-mail, fai clic sul pulsante in basso.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Hai cambiato correttamente il tuo nome utente.<br>Il tuo nuovo nome utente è {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Devi trasferire la proprietà o cancellare gli spazi prima di eliminare il tuo account.',
    'Your account cannot be deleted!' => 'Il tuo account non può essere eliminato!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'La tua email attuale è <b>{email}</b>. Puoi modificarla qui.',
    'Your current password can be changed here.' => 'Puoi cambiare la tua password qui.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Il tuo nome utente corrente è <b> {username} </b>. Puoi cambiare il tuo nome utente corrente qui.',
    'Your e-mail address has been successfully changed to {email}.' => 'Il tuo indirizzo e-mail è stato cambiato con successo a {email}.',
    'Your friends' => 'I tuoi amici',
    'Your password has been successfully changed!' => 'La tua password è stata cambiata con successo!',
    'Your username has been changed' => 'Il tuo nome utente è stato cambiato',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Il tuo nome utente è stato modificato con successo. <br> Ti abbiamo appena inviato un\'e-mail con nuove informazioni.',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
    'Plain' => '',
    'Rich Text' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/it/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => 'Impostazioni dell\'<strong>account</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Conferma</strong> il tuo nuovo indirizzo email',
    '<strong>Permissions</strong>' => '<strong>Autorizzazioni</strong>',
    '<strong>Your</strong> Account' => 'Il <strong>Tuo</strong> Account',
    '<strong>Your</strong> profile' => '<strong>Il tuo</strong> profilo',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Aggiungi tag al tuo profilo descrivendoti ed evidenziando le tue capacità e i tuoi interessi. I tuoi tag verranno visualizzati nel tuo profilo e nella directory "Persone".',
    'All your personal data will be irrevocably deleted.' => 'Tutti i tuoi dati personali verranno definitivamente eliminati.',
    'Are you sure that you want to delete your account?' => 'Sei sicuro di voler eliminare il tuo account?',
    'Blocked users' => 'Utenti bloccati',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'La modifica del nome utente può rendere inutilizzabili alcuni collegamenti, ad esempio vecchi collegamenti al profilo.',
    'Confirm' => 'Conferma',
    'Current password' => 'Password attuale',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Definisci le impostazioni di base per il tuo profilo. Puoi aggiungere tag adatti a te, scegliere la lingua e il fuso orario e bloccare gli utenti maleducati.',
    'Delete account' => 'Elimina account',
    'Do you really want to delete your icon image?' => 'Vuoi veramente cancellare l\'immagine dell\'icona?',
    'Do you really want to delete your logo image?' => 'Vuoi veramente eliminare la tua immagine?',
    'E-Mail' => 'Email',
    'E-Mail change' => 'Cambia e-mail',
    'Enter your password to continue' => 'Inserisci la tua password per continuare',
    'General' => 'Generale',
    'Hello' => 'Ciao',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Qui puoi modificare i tuoi dati generali del profilo, che sono visibili nella pagina personale del tuo profilo.',
    'Hide introduction tour panel on dashboard' => 'Nascondi il pannello tour introduttivo sulla bacheca',
    'Hide my online status' => 'Nascondere il mio stato online',
    'Invalid link! Please make sure that you entered the entire url.' => 'Link non valido! Assicurati di aver inserito l\'intero URL.',
    'Language' => 'Lingua',
    'Markdown Editor Mode' => 'Modalità editor Markdown',
    'Modules' => 'Moduli',
    'New E-Mail address' => 'Nuovo indirizzo e-mail',
    'New User name' => 'Nuovo nome utente',
    'Not registered users' => 'Utenti non registrati',
    'Notifications' => 'Notifiche',
    'Other users' => 'Altri utenti',
    'Password Recovery' => 'Recupera password',
    'Permissions' => 'Permessi',
    'Profile' => 'Profilo',
    'Profile Tags' => 'Tag del profilo',
    'Profile visibility' => 'Visibilità profilo',
    'Registered users only' => 'Solo utenti registrati',
    'Save' => 'Salva',
    'Save profile' => 'Salva il profilo',
    'The entered e-mail address is already in use by another user.' => 'La mail inserita è già stata utilizzata da un altro utente.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Queste impostazioni ti consentono di determinare quali autorizzazioni vuoi concedere ai visitatori del tuo profilo personale. Ogni utente può regolare liberamente le impostazioni per il proprio profilo.',
    'TimeZone' => 'Fuso orario',
    'Username has been changed' => 'Il nome utente è stato cambiato',
    'Users' => 'Persone',
    'Visible for all (also unregistered users)' => 'Visibile a tutti (anche utenti non registrati)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Abbiamo appena inviato un\'e-mail di conferma al tuo nuovo indirizzo. <br> Si prega di seguire le istruzioni all\'interno.',
    'You are currently the owner of following spaces:' => 'Sei il proprietario dei seguenti spazi:',
    'You cannot use this username.' => 'Non puoi usare questo nome utente.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Hai richiesto di modificare il tuo indirizzo e-mail.<br>Il tuo nuovo indirizzo e-mail è {newemail}.<br><br>Per confermare il tuo nuovo indirizzo e-mail, fai clic sul pulsante in basso.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Hai cambiato correttamente il tuo nome utente.<br>Il tuo nuovo nome utente è {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Devi trasferire la proprietà o cancellare gli spazi prima di eliminare il tuo account.',
    'Your account cannot be deleted!' => 'Il tuo account non può essere eliminato!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'La tua email attuale è <b>{email}</b>. Puoi modificarla qui.',
    'Your current password can be changed here.' => 'Puoi cambiare la tua password qui.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Il tuo nome utente corrente è <b> {username} </b>. Puoi cambiare il tuo nome utente corrente qui.',
    'Your e-mail address has been successfully changed to {email}.' => 'Il tuo indirizzo e-mail è stato cambiato con successo a {email}.',
    'Your friends' => 'I tuoi amici',
    'Your password has been successfully changed!' => 'La tua password è stata cambiata con successo!',
    'Your username has been changed' => 'Il tuo nome utente è stato cambiato',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Il tuo nome utente è stato modificato con successo. <br> Ti abbiamo appena inviato un\'e-mail con nuove informazioni.',
    'Do you really want to delete your login background image?' => '',
    'Do you really want to delete your mail header image?' => '',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
    'Plain' => '',
    'Rich Text' => '',
];
